==> bokeh-2.3.0.dev5.tar.gz: bokeh-2.3.0.dev5/bokeh/server/static/js/types/core/enums.d.ts <==
export declare type Align = "start" | "center" | "end";
export declare const Align: import("./kinds").Kinds.Enum<"start" | "center" | "end">;
export declare type Anchor = "top_left" | "top_center" | "top_right" | "center_left" | "center" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right";
export declare const Anchor: import("./kinds").Kinds.Enum<"center" | "top_left" | "top_center" | "top_right" | "center_left" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right">;
export declare type AngleUnits = "deg" | "rad";
export declare const AngleUnits: import("./kinds").Kinds.Enum<"deg" | "rad">;
export declare type BoxOrigin = "corner" | "center";
export declare const BoxOrigin: import("./kinds").Kinds.Enum<"center" | "corner">;
export declare type ButtonType = "default" | "primary" | "success" | "warning" | "danger";
export declare const ButtonType: import("./kinds").Kinds.Enum<"default" | "primary" | "success" | "warning" | "danger">;
export declare type CalendarPosition = "auto" | "above" | "below";
export declare const CalendarPosition: import("./kinds").Kinds.Enum<"auto" | "above" | "below">;
export declare type Dimension = "width" | "height";
export declare const Dimension: import("./kinds").Kinds.Enum<"width" | "height">;
export declare type Dimensions = "width" | "height" | "both";
export declare const Dimensions: import("./kinds").Kinds.Enum<"width" | "height" | "both">;
export declare type Direction = "clock" | "anticlock";
export declare const Direction: import("./kinds").Kinds.Enum<"clock" | "anticlock">;
export declare type Distribution = "uniform" | "normal";
export declare const Distribution: import("./kinds").Kinds.Enum<"uniform" | "normal">;
export declare type FontStyle = "normal" | "italic" | "bold" | "bold italic";
export declare const FontStyle: import("./kinds").Kinds.Enum<"bold" | "normal" | "italic" | "bold italic">;
export declare type HatchPatternType = 'blank' | 'dot' | 'ring' | 'horizontal_line' | 'vertical_line' | 'cross' | 'horizontal_dash' | 'vertical_dash' | 'spiral' | 'right_diagonal_line' | 'left_diagonal_line' | 'diagonal_cross' | 'right_diagonal_dash' | 'left_diagonal_dash' | 'horizontal_wave' | 'vertical_wave' | 'criss_cross' | ' ' | '.' | 'o' | '-' | '|' | '+' | '"' | ':' | '@' | '/' | '\\' | 'x' | ',' | '`' | 'v' | '>' | '*';
export declare const HatchPatternType: import("./kinds").Kinds.Enum<"," | "blank" | "dot" | "ring" | "horizontal_line" | "vertical_line" | "cross" | "horizontal_dash" | "vertical_dash" | "spiral" | "right_diagonal_line" | "left_diagonal_line" | "diagonal_cross" | "right_diagonal_dash" | "left_diagonal_dash" | "horizontal_wave" | "vertical_wave" | "criss_cross" | " " | "." | "o" | "-" | "|" | "+" | "\"" | ":" | "@" | "/" | "\\" | "x" | "`" | "v" | ">" | "*">;
export declare type HTTPMethod = "POST" | "GET";
export declare const HTTPMethod: import("./kinds").Kinds.Enum<"POST" | "GET">;
export declare type HexTileOrientation = "pointytop" | "flattop";
export declare const HexTileOrientation: import("./kinds").Kinds.Enum<"pointytop" | "flattop">;
export declare type HoverMode = "mouse" | "hline" | "vline";
export declare const HoverMode: import("./kinds").Kinds.Enum<"mouse" | "hline" | "vline">;
export declare type LatLon = "lat" | "lon";
export declare const LatLon: import("./kinds").Kinds.Enum<"lat" | "lon">;
export declare type LegendClickPolicy = "none" | "hide" | "mute";
export declare const LegendClickPolicy: import("./kinds").Kinds.Enum<"none" | "hide" | "mute">;
export declare type LegendLocation = Anchor;
export declare const LegendLocation: import("./kinds").Kinds.Enum<"center" | "top_left" | "top_center" | "top_right" | "center_left" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right">;
export declare type LineCap = "butt" | "round" | "square";
export declare const LineCap: import("./kinds").Kinds.Enum<"butt" | "round" | "square">;
export declare type LineJoin = "miter" | "round" | "bevel";
export declare const LineJoin: import("./kinds").Kinds.Enum<"round" | "miter" | "bevel">;
export declare type LinePolicy = "prev" | "next" | "nearest" | "interp" | "none";
export declare const LinePolicy: import("./kinds").Kinds.Enum<"none" | "prev" | "next" | "nearest" | "interp">;
export declare type Location = "above" | "below" | "left" | "right";
export declare const Location: import("./kinds").Kinds.Enum<"above" | "below" | "left" | "right">;
export declare type Logo = "normal" | "grey";
export declare const Logo: import("./kinds").Kinds.Enum<"grey" | "normal">;
export declare type MarkerType = "asterisk" | "circle" | "circle_cross" | "circle_dot" | "circle_x" | "circle_y" | "cross" | "dash" | "diamond" | "diamond_cross" | "diamond_dot" | "dot" | "hex" | "hex_dot" | "inverted_triangle" | "plus" | "square" | "square_cross" | "square_dot" | "square_pin" | "square_x" | "triangle" | "triangle_dot" | "triangle_pin" | "x" | "y";
export declare const MarkerType: import("./kinds").Kinds.Enum<"dot" | "cross" | "x" | "square" | "asterisk" | "circle" | "circle_cross" | "circle_dot" | "circle_x" | "circle_y" | "dash" | "diamond" | "diamond_cross" | "diamond_dot" | "hex" | "hex_dot" | "inverted_triangle" | "plus" | "square_cross" | "square_dot" | "square_pin" | "square_x" | "triangle" | "triangle_dot" | "triangle_pin" | "y">;
export declare type MutedPolicy = "show" | "ignore";
export declare const MutedPolicy: import("./kinds").Kinds.Enum<"show" | "ignore">;
export declare type Orientation = "vertical" | "horizontal";
export declare const Orientation: import("./kinds").Kinds.Enum<"vertical" | "horizontal">;
export declare type OutputBackend = "canvas" | "svg" | "webgl";
export declare const OutputBackend: import("./kinds").Kinds.Enum<"canvas" | "svg" | "webgl">;
export declare type PaddingUnits = "percent" | "absolute";
export declare const PaddingUnits: import("./kinds").Kinds.Enum<"percent" | "absolute">;
export declare type Place = Side | "center";
export declare const Place: import("./kinds").Kinds.Enum<"center" | "above" | "below" | "left" | "right">;
export declare type PointPolicy = "snap_to_data" | "follow_mouse" | "none";
export declare const PointPolicy: import("./kinds").Kinds.Enum<"none" | "snap_to_data" | "follow_mouse">;
export declare type RadiusDimension = "x" | "y" | "max" | "min";
export declare const RadiusDimension: import("./kinds").Kinds.Enum<"max" | "x" | "y" | "min">;
export declare type RenderLevel = "image" | "underlay" | "glyph" | "guide" | "annotation" | "overlay";
export declare const RenderLevel: import("./kinds").Kinds.Enum<"image" | "underlay" | "glyph" | "guide" | "annotation" | "overlay">;
export declare type RenderMode = "canvas" | "css";
export declare const RenderMode: import("./kinds").Kinds.Enum<"canvas" | "css">;
export declare type ResetPolicy = "standard" | "event_only";
export declare const ResetPolicy: import("./kinds").Kinds.Enum<"standard" | "event_only">;
export declare type RoundingFunction = "round" | "nearest" | "floor" | "rounddown" | "ceil" | "roundup";
export declare const RoundingFunction: import("./kinds").Kinds.Enum<"ceil" | "round" | "nearest" | "floor" | "rounddown" | "roundup">;
export declare type SelectionMode = "replace" | "append" | "intersect" | "subtract";
export declare const SelectionMode: import("./kinds").Kinds.Enum<"replace" | "append" | "intersect" | "subtract">;
export declare type Side = "above" | "below" | "left" | "right";
export declare const Side: import("./kinds").Kinds.Enum<"above" | "below" | "left" | "right">;
export declare type SizingMode = "stretch_width" | "stretch_height" | "stretch_both" | "scale_width" | "scale_height" | "scale_both" | "fixed";
export declare const SizingMode: import("./kinds").Kinds.Enum<"fixed" | "stretch_width" | "stretch_height" | "stretch_both" | "scale_width" | "scale_height" | "scale_both">;
export declare type Sort = "ascending" | "descending";
export declare const Sort: import("./kinds").Kinds.Enum<"ascending" | "descending">;
export declare type SpatialUnits = "screen" | "data";
export declare const SpatialUnits: import("./kinds").Kinds.Enum<"screen" | "data">;
export declare type StartEnd = "start" | "end";
export declare const StartEnd: import("./kinds").Kinds.Enum<"start" | "end">;
export declare type StepMode = "after" | "before" | "center";
export declare const StepMode: import("./kinds").Kinds.Enum<"center" | "after" | "before">;
export declare type TapBehavior = "select" | "inspect";
export declare const TapBehavior: import("./kinds").Kinds.Enum<"select" | "inspect">;
export declare type TextAlign = "left" | "right" | "center";
export declare const TextAlign: import("./kinds").Kinds.Enum<"center" | "left" | "right">;
export declare type TextBaseline = "top" | "middle" | "bottom" | "alphabetic" | "hanging" | "ideographic";
export declare const TextBaseline: import("./kinds").Kinds.Enum<"top" | "middle" | "bottom" | "alphabetic" | "hanging" | "ideographic">;
export declare type TextureRepetition = "repeat" | "repeat_x" | "repeat_y" | "no_repeat";
export declare const TextureRepetition: import("./kinds").Kinds.Enum<"repeat" | "repeat_x" | "repeat_y" | "no_repeat">;
export declare type TickLabelOrientation = "vertical" | "horizontal" | "parallel" | "normal";
export declare const TickLabelOrientation: import("./kinds").Kinds.Enum<"normal" | "vertical" | "horizontal" | "parallel">;
export declare type TooltipAttachment = "horizontal" | "vertical" | "left" | "right" | "above" | "below";
export declare const TooltipAttachment: import("./kinds").Kinds.Enum<"above" | "below" | "left" | "right" | "vertical" | "horizontal">;
export declare type UpdateMode = "replace" | "append";
export declare const UpdateMode: import("./kinds").Kinds.Enum<"replace" | "append">;
export declare type VerticalAlign = "top" | "middle" | "bottom";
export declare const VerticalAlign: import("./kinds").Kinds.Enum<"top" | "middle" | "bottom">;
//# sourceMappingURL=enums.d.ts.map

==> bokeh-2.4.3.tar.gz: bokeh-2.4.3/bokeh/server/static/js/types/core/enums.d.ts <==
export declare type Align = "start" | "center" | "end";
export declare const Align: import("./kinds").Kinds.Enum<"start" | "center" | "end">;
export declare type Anchor = "top_left" | "top_center" | "top_right" | "center_left" | "center_center" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right" | "top" | "left" | "center" | "right" | "bottom";
export declare const Anchor: import("./kinds").Kinds.Enum<"center" | "top_left" | "top_center" | "top_right" | "center_left" | "center_center" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right" | "top" | "left" | "right" | "bottom">;
export declare type AngleUnits = "deg" | "rad" | "grad" | "turn";
export declare const AngleUnits: import("./kinds").Kinds.Enum<"deg" | "rad" | "grad" | "turn">;
export declare type BoxOrigin = "corner" | "center";
export declare const BoxOrigin: import("./kinds").Kinds.Enum<"center" | "corner">;
export declare type ButtonType = "default" | "primary" | "success" | "warning" | "danger" | "light";
export declare const ButtonType: import("./kinds").Kinds.Enum<"default" | "primary" | "success" | "warning" | "danger" | "light">;
export declare type CalendarPosition = "auto" | "above" | "below";
export declare const CalendarPosition: import("./kinds").Kinds.Enum<"auto" | "above" | "below">;
export declare type Dimension = "width" | "height";
export declare const Dimension: import("./kinds").Kinds.Enum<"width" | "height">;
export declare type Dimensions = "width" | "height" | "both";
export declare const Dimensions: import("./kinds").Kinds.Enum<"width" | "height" | "both">;
export declare type Direction = "clock" | "anticlock";
export declare const Direction: import("./kinds").Kinds.Enum<"clock" | "anticlock">;
export declare type Distribution = "uniform" | "normal";
export declare const Distribution: import("./kinds").Kinds.Enum<"uniform" | "normal">;
export declare type FontStyle = "normal" | "italic" | "bold" | "bold italic";
export declare const FontStyle: import("./kinds").Kinds.Enum<"bold" | "normal" | "italic" | "bold italic">;
export declare type HatchPatternType = "blank" | "dot" | "ring" | "horizontal_line" | "vertical_line" | "cross" | "horizontal_dash" | "vertical_dash" | "spiral" | "right_diagonal_line" | "left_diagonal_line" | "diagonal_cross" | "right_diagonal_dash" | "left_diagonal_dash" | "horizontal_wave" | "vertical_wave" | "criss_cross" | " " | "." | "o" | "-" | "|" | "+" | '"' | ":" | "@" | "/" | "\\" | "x" | "," | "`" | "v" | ">" | "*";
export declare const HatchPatternType: import("./kinds").Kinds.Enum<"blank" | "dot" | "ring" | "horizontal_line" | "vertical_line" | "cross" | "horizontal_dash" | "vertical_dash" | "spiral" | "right_diagonal_line" | "left_diagonal_line" | "diagonal_cross" | "right_diagonal_dash" | "left_diagonal_dash" | "horizontal_wave" | "vertical_wave" | "criss_cross" | " " | "." | "o" | "-" | "|" | "+" | "\"" | ":" | "@" | "/" | "\\" | "x" | "," | "`" | "v" | ">" | "*">;
export declare type HTTPMethod = "POST" | "GET";
export declare const HTTPMethod: import("./kinds").Kinds.Enum<"POST" | "GET">;
export declare type HexTileOrientation = "pointytop" | "flattop";
export declare const HexTileOrientation: import("./kinds").Kinds.Enum<"pointytop" | "flattop">;
export declare type HoverMode = "mouse" | "hline" | "vline";
export declare const HoverMode: import("./kinds").Kinds.Enum<"mouse" | "hline" | "vline">;
export declare type LatLon = "lat" | "lon";
export declare const LatLon: import("./kinds").Kinds.Enum<"lat" | "lon">;
export declare type LegendClickPolicy = "none" | "hide" | "mute";
export declare const LegendClickPolicy: import("./kinds").Kinds.Enum<"none" | "hide" | "mute">;
export declare type LegendLocation = Anchor;
export declare const LegendLocation: import("./kinds").Kinds.Enum<"center" | "top_left" | "top_center" | "top_right" | "center_left" | "center_center" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right" | "top" | "left" | "right" | "bottom">;
export declare type LineCap = "butt" | "round" | "square";
export declare const LineCap: import("./kinds").Kinds.Enum<"round" | "butt" | "square">;
export declare type LineJoin = "miter" | "round" | "bevel";
export declare const LineJoin: import("./kinds").Kinds.Enum<"round" | "miter" | "bevel">;
export declare type LineDash = "solid" | "dashed" | "dotted" | "dotdash" | "dashdot";
export declare const LineDash: import("./kinds").Kinds.Enum<"solid" | "dashed" | "dotted" | "dotdash" | "dashdot">;
export declare type LinePolicy = "prev" | "next" | "nearest" | "interp" | "none";
export declare const LinePolicy: import("./kinds").Kinds.Enum<"none" | "prev" | "next" | "nearest" | "interp">;
export declare type Location = "above" | "below" | "left" | "right";
export declare const Location: import("./kinds").Kinds.Enum<"left" | "right" | "above" | "below">;
export declare type Logo = "normal" | "grey";
export declare const Logo: import("./kinds").Kinds.Enum<"grey" | "normal">;
export declare type MarkerType = "asterisk" | "circle" | "circle_cross" | "circle_dot" | "circle_x" | "circle_y" | "cross" | "dash" | "diamond" | "diamond_cross" | "diamond_dot" | "dot" | "hex" | "hex_dot" | "inverted_triangle" | "plus" | "square" | "square_cross" | "square_dot" | "square_pin" | "square_x" | "star" | "star_dot" | "triangle" | "triangle_dot" | "triangle_pin" | "x" | "y";
export declare const MarkerType: import("./kinds").Kinds.Enum<"dot" | "cross" | "x" | "square" | "asterisk" | "circle" | "circle_cross" | "circle_dot" | "circle_x" | "circle_y" | "dash" | "diamond" | "diamond_cross" | "diamond_dot" | "hex" | "hex_dot" | "inverted_triangle" | "plus" | "square_cross" | "square_dot" | "square_pin" | "square_x" | "star" | "star_dot" | "triangle" | "triangle_dot" | "triangle_pin" | "y">;
export declare type MutedPolicy = "show" | "ignore";
export declare const MutedPolicy: import("./kinds").Kinds.Enum<"show" | "ignore">;
export declare type Orientation = "vertical" | "horizontal";
export declare const Orientation: import("./kinds").Kinds.Enum<"vertical" | "horizontal">;
export declare type OutputBackend = "canvas" | "svg" | "webgl";
export declare const OutputBackend: import("./kinds").Kinds.Enum<"canvas" | "svg" | "webgl">;
export declare type PaddingUnits = "percent" | "absolute";
export declare const PaddingUnits: import("./kinds").Kinds.Enum<"percent" | "absolute">;
export declare type Place = Side | "center";
export declare const Place: import("./kinds").Kinds.Enum<"center" | "left" | "right" | "above" | "below">;
export declare type PointPolicy = "snap_to_data" | "follow_mouse" | "none";
export declare const PointPolicy: import("./kinds").Kinds.Enum<"none" | "snap_to_data" | "follow_mouse">;
export declare type RadiusDimension = "x" | "y" | "max" | "min";
export declare const RadiusDimension: import("./kinds").Kinds.Enum<"x" | "y" | "max" | "min">;
export declare type RenderLevel = "image" | "underlay" | "glyph" | "guide" | "annotation" | "overlay";
export declare const RenderLevel: import("./kinds").Kinds.Enum<"image" | "underlay" | "glyph" | "guide" | "annotation" | "overlay">;
export declare type RenderMode = "canvas" | "css";
export declare const RenderMode: import("./kinds").Kinds.Enum<"canvas" | "css">;
export declare type ResetPolicy = "standard" | "event_only";
export declare const ResetPolicy: import("./kinds").Kinds.Enum<"standard" | "event_only">;
export declare type RoundingFunction = "round" | "nearest" | "floor" | "rounddown" | "ceil" | "roundup";
export declare const RoundingFunction: import("./kinds").Kinds.Enum<"round" | "nearest" | "floor" | "rounddown" | "ceil" | "roundup">;
export declare type SelectionMode = "replace" | "append" | "intersect" | "subtract";
export declare const SelectionMode: import("./kinds").Kinds.Enum<"replace" | "append" | "intersect" | "subtract">;
export declare type Side = "above" | "below" | "left" | "right";
export declare const Side: import("./kinds").Kinds.Enum<"left" | "right" | "above" | "below">;
export declare type SizingMode = "stretch_width" | "stretch_height" | "stretch_both" | "scale_width" | "scale_height" | "scale_both" | "fixed";
export declare const SizingMode: import("./kinds").Kinds.Enum<"fixed" | "stretch_width" | "stretch_height" | "stretch_both" | "scale_width" | "scale_height" | "scale_both">;
export declare type Sort = "ascending" | "descending";
export declare const Sort: import("./kinds").Kinds.Enum<"ascending" | "descending">;
export declare type SpatialUnits = "screen" | "data";
export declare const SpatialUnits: import("./kinds").Kinds.Enum<"data" | "screen">;
export declare type StartEnd = "start" | "end";
export declare const StartEnd: import("./kinds").Kinds.Enum<"start" | "end">;
export declare type StepMode = "after" | "before" | "center";
export declare const StepMode: import("./kinds").Kinds.Enum<"center" | "after" | "before">;
export declare type TapBehavior = "select" | "inspect";
export declare const TapBehavior: import("./kinds").Kinds.Enum<"select" | "inspect">;
export declare type TextAlign = "left" | "right" | "center";
export declare const TextAlign: import("./kinds").Kinds.Enum<"center" | "left" | "right">;
export declare type TextBaseline = "top" | "middle" | "bottom" | "alphabetic" | "hanging" | "ideographic";
export declare const TextBaseline: import("./kinds").Kinds.Enum<"top" | "bottom" | "middle" | "alphabetic" | "hanging" | "ideographic">;
export declare type TextureRepetition = "repeat" | "repeat_x" | "repeat_y" | "no_repeat";
export declare const TextureRepetition: import("./kinds").Kinds.Enum<"repeat" | "repeat_x" | "repeat_y" | "no_repeat">;
export declare type TickLabelOrientation = "vertical" | "horizontal" | "parallel" | "normal";
export declare const TickLabelOrientation: import("./kinds").Kinds.Enum<"normal" | "vertical" | "horizontal" | "parallel">;
export declare type TooltipAttachment = "horizontal" | "vertical" | "left" | "right" | "above" | "below";
export declare const TooltipAttachment: import("./kinds").Kinds.Enum<"left" | "right" | "above" | "below" | "vertical" | "horizontal">;
export declare type UpdateMode = "replace" | "append";
export declare const UpdateMode: import("./kinds").Kinds.Enum<"replace" | "append">;
export declare type VerticalAlign = "top" | "middle" | "bottom";
export declare const VerticalAlign: import("./kinds").Kinds.Enum<"top" | "bottom" | "middle">;
//# sourceMappingURL=enums.d.ts.map
